@@ -31,6 +31,7 @@
 namespace Okular {
 class ObjectRect;
 class SourceReference;
+class SignatureInfo;
 }
 
 class PDFOptionsPage;
@@ -39,7 +40,7 @@ class PopplerAnnotationProxy;
 /**
  * @short A generator that builds contents from a PDF document.
  *
- * All Generator features are supported and implented by this one.
+ * All Generator features are supported and implemented by this one.
  * Internally this holds a reference to xpdf's core objects and provides
  * contents generation using the PDFDoc object and a couple of OutputDevices
  * called Okular::OutputDev and Okular::TextDev (both defined in gp_outputdev.h).
@@ -113,7 +114,7 @@ class PDFGenerator : public Okular::Generator, public Okular::ConfigInterface, p
     private:
         Okular::Document::OpenResult init(QVector<Okular::Page*> & pagesVector, const QString &password);
 
-        // create the document synopsis hieracy
+        // create the document synopsis hierarchy
         void addSynopsisChildren( QDomNode * parentSource, QDomNode * parentDestination );
         // fetch annotations from the pdf file and add they to the page
         void addAnnotations( Poppler::Page * popplerPage, Okular::Page * page );
@@ -129,7 +130,7 @@ class PDFGenerator : public Okular::Generator, public Okular::ConfigInterface, p
 
         bool setDocumentRenderHints();
 
-        // poppler dependant stuff
+        // poppler dependent stuff
         Poppler::Document *pdfdoc;
 
 
